==> mathmoon-0.0.1.tar.bz2: mathmoon-0.0.1/src/multsim/multsimpanel.h <==
// A mathematical game
// Copyright (C) 2004 by Christian von Schultz <schultz@linux.nu>

// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


#ifndef MULTSIMPANEL_H
#define MULTSIMPANEL_H

#include <wx/object.h>
#include <wx/wxexpr.h>
#include <wx/panel.h>
#include <wx/timer.h>
#include <new>
#include <list>
using std::list;

#include <config.h>
#include "../checksetup.h"
#include "../exceptions.h"
#include "../mainwindow.h"
#include "selfcorr.h"

class MultSim;

class MultSimPanel: public wxPanel
{
public:
  MultSimPanel(MultSim *ms, const wxExpr *expr)
               throw(Exception);
  virtual ~MultSimPanel();

  void Start() throw();

  void GiveOneFocus() throw();

  void OnTimer(wxTimerEvent &event) throw();

  void SaveData(const wxString &title) throw();

  void LoadData() throw();

protected:
  DECLARE_EVENT_TABLE();

private:
  MultSim *m_ms;
  wxTimer *m_timer;
  list<SelfCorrecting*> m_sc;
};

enum { TIMER_ID = ID_HIGHEST + 1 };

#include "multsim.h"

#endif // MULTSIMPANEL_H

// 
// Local Variables:
// mode: c++
// End:

==> mathmoon-0.1.0.tar.bz2: mathmoon-0.1.0/src/multsim/multsimpanel.h <==
// A mathematical game
// Copyright (C) 2004 by Christian von Schultz <schultz@linux.nu>

// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


#ifndef MULTSIMPANEL_H
#define MULTSIMPANEL_H

#include <wx/object.h>
#include <wx/wxexpr.h>
#include <wx/panel.h>
#include <wx/timer.h>
#include <wx/dc.h>
#include <new>
#include <list>
using std::list;

#include <config.h>
#include "../checksetup.h"
#include "../exceptions.h"
#include "../mainwindow.h"
#include "selfcorr.h"

class MultSim;

class MultSimPanel: public wxPanel
{
public:
  MultSimPanel(MultSim *ms, const wxExpr *expr)
               throw(Exception);
  virtual ~MultSimPanel();

  void Start() throw();

  void GiveOneFocus() throw();

  void SaveData(const wxString &title) throw();
  void LoadData() throw();

  void OnPaint(wxPaintEvent &event) throw();
  void Draw(wxDC &dc) throw();

protected:
  DECLARE_EVENT_TABLE();

private:
  MultSim *m_ms;
  list<SelfCorrecting*> m_sc;
};

#include "multsim.h"

#endif // MULTSIMPANEL_H

// 
// Local Variables:
// mode: c++
// End:
